@@ -1,10 +1,5 @@
 package Tree::FSMethods;
 
-our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-06-27'; # DATE
-our $DIST = 'Tree-FSMethods'; # DIST
-our $VERSION = '0.003'; # VERSION
-
 use 5.010001;
 use strict;
 use warnings;
@@ -15,6 +10,11 @@ use Scalar::Util qw(refaddr);
 use Storable qw(dclone);
 use String::Wildcard::Bash;
 
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2021-10-07'; # DATE
+our $DIST = 'Tree-FSMethods'; # DIST
+our $VERSION = '0.004'; # VERSION
+
 sub new {
     my ($class, %args) = (shift, @_);
 
@@ -471,7 +471,7 @@ Tree::FSMethods - Perform filesystem-like operations on object tree(s)
 
 =head1 VERSION
 
-This document describes version 0.003 of Tree::FSMethods (from Perl distribution Tree-FSMethods), released on 2021-06-27.
+This document describes version 0.004 of Tree::FSMethods (from Perl distribution Tree-FSMethods), released on 2021-10-07.
 
 =head1 SYNOPSIS
 
@@ -669,6 +669,38 @@ Please visit the project's homepage at L<https://metacpan.org/release/Tree-FSMet
 
 Source repository is at L<https://github.com/perlancar/perl-Tree-FSMethods>.
 
+=head1 SEE ALSO
+
+L<RoleBundle::TinyCommons::Tree>
+
+=head1 AUTHOR
+
+perlancar <perlancar@cpan.org>
+
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
+beyond that are considered a bug and can be reported to me.
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2021, 2020 by perlancar <perlancar@cpan.org>.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Tree-FSMethods>
@@ -677,19 +709,4 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
-=head1 SEE ALSO
-
-L<Role::TinyCommons::Tree>
-
-=head1 AUTHOR
-
-perlancar <perlancar@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2021, 2020 by perlancar@cpan.org.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
